@@ -1,5 +1,5 @@
 //-----------------------------------------------------------------------------
-/** @file CoordPoint.cpp */
+/** @file libboardgame_base/CoordPoint.cpp */
 //-----------------------------------------------------------------------------
 
 #ifdef HAVE_CONFIG_H
@@ -9,7 +9,6 @@
 #include "CoordPoint.h"
 
 #include <iostream>
-#include <boost/foreach.hpp>
 
 namespace libboardgame_base {
 
