@@ -1,17 +1,15 @@
 //-----------------------------------------------------------------------------
-/** @file Failure.h */
+/** @file libboardgame_gtp/Failure.h */
 //-----------------------------------------------------------------------------
 
 #ifndef LIBBOARDGAME_GTP_FAILURE_H
 #define LIBBOARDGAME_GTP_FAILURE_H
 
 #include <string>
-#include <boost/format.hpp>
 
 namespace libboardgame_gtp {
 
 using namespace std;
-using boost::format;
 
 //-----------------------------------------------------------------------------
 
@@ -23,8 +21,6 @@ class Failure
 public:
     Failure(const string& response = "");
 
-    Failure(const format& response);
-
     ~Failure() throw();
 
     string get_response() const;
@@ -38,11 +34,6 @@ inline Failure::Failure(const string& response)
 {
 }
 
-inline Failure::Failure(const format& response)
-    : m_response(response.str())
-{
-}
-
 inline Failure::~Failure() throw()
 {
 }
