@@ -9,22 +9,34 @@ namespace libboardgame_mcts {
 
 //-----------------------------------------------------------------------------
 
+typedef uint_fast8_t PlayerInt;
+
+//-----------------------------------------------------------------------------
+
 template<typename MOVE>
 struct PlayerMove
 {
-    unsigned int player;
+    PlayerInt player;
 
     MOVE move;
 
-    PlayerMove(unsigned int player, MOVE move);
-};
+    static PlayerMove null()
+    {
+        PlayerMove m;
+        m.move = MOVE::null();
+        return m;
+    }
 
-template<typename MOVE>
-inline PlayerMove<MOVE>::PlayerMove(unsigned int player, MOVE move)
-{
-    this->player = player;
-    this->move = move;
-}
+    PlayerMove()
+    {
+    }
+
+    PlayerMove(PlayerInt player, MOVE move)
+    {
+        this->player = player;
+        this->move = move;
+    }
+};
 
 //-----------------------------------------------------------------------------
 
