@@ -1,26 +1,33 @@
 //-----------------------------------------------------------------------------
-/** @file TreeUtil.h */
+/** @file libboardgame_mcts/TreeUtil.h */
 //-----------------------------------------------------------------------------
 
 #ifndef LIBBOARDGAME_MCTS_TREE_UTIL_H
 #define LIBBOARDGAME_MCTS_TREE_UTIL_H
 
-#include "NodeUtil.h"
+#include "ChildIterator.h"
 #include "Tree.h"
 
 namespace libboardgame_mcts {
 namespace tree_util {
 
-using libboardgame_mcts::node_util::find_child;
-
 //-----------------------------------------------------------------------------
 
-template<typename M, class S>
-const Node<M>* find_node(const Tree<M>& tree, const S& sequence)
+template<typename N>
+const N* find_child(const Tree<N>& tree, const N& node, typename N::Move mv)
 {
-    const Node<M>* node = &tree.get_root();
-    BOOST_FOREACH(M mv, sequence)
-        if ((node = find_child(*node, mv)) == 0)
+    for (ChildIterator<N> i(tree, node); i; ++i)
+        if (i->get_move() == mv)
+            return &(*i);
+    return nullptr;
+}
+
+template<typename N, class S>
+const N* find_node(const Tree<N>& tree, const S& sequence)
+{
+    auto node = &tree.get_root();
+    for (auto mv : sequence)
+        if ((node = find_child(tree, *node, mv)) == nullptr)
             break;
     return node;
 }
