@@ -5,33 +5,44 @@
 #ifndef LIBBOARDGAME_SGF_INVALID_PROPERTY_VALUE_H
 #define LIBBOARDGAME_SGF_INVALID_PROPERTY_VALUE_H
 
-#include "libboardgame_util/Exception.h"
+#include "InvalidTree.h"
+
+#include "sstream"
 
 namespace libboardgame_sgf {
 
 using namespace std;
-using boost::format;
-using libboardgame_util::Exception;
 
 //-----------------------------------------------------------------------------
 
 class InvalidPropertyValue
-    : public Exception
+    : public InvalidTree
 {
 public:
     template<typename T>
     InvalidPropertyValue(const string& id, const T& value);
 
     ~InvalidPropertyValue() throw();
+
+private:
+    template<typename T>
+    static string get_message(const string& id, const T& value);
 };
 
 template<typename T>
 InvalidPropertyValue::InvalidPropertyValue(const string& id, const T& value)
-    : Exception(format("Invalid value '%1%' for SGF property '%2%'")
-                % value % id)
+    : InvalidTree(get_message(id, value))
 {
 }
 
+template<typename T>
+string InvalidPropertyValue::get_message(const string& id, const T& value)
+{
+    ostringstream msg;
+    msg << "Invalid value '" << value << " for SGF property '" << id << "'";
+    return msg.str();
+}
+
 //-----------------------------------------------------------------------------
 
 } // namespace libboardgame_sgf
