@@ -15,23 +15,23 @@ namespace libboardgame_sgf {
 void TreeIterator::operator++()
 {
     LIBBOARDGAME_ASSERT(operator bool());
-    const Node* first_child = m_current->get_first_child_or_null();
-    if (first_child != 0)
+    auto first_child = m_current->get_first_child_or_null();
+    if (first_child != nullptr)
     {
         m_current = first_child;
         return;
     }
     if (m_current == &m_root)
     {
-        m_current = 0;
+        m_current = nullptr;
         return;
     }
-    while (m_current->get_sibling() == 0)
+    while (m_current->get_sibling() == nullptr)
     {
         m_current = &m_current->get_parent();
         if (m_current == &m_root)
         {
-            m_current = 0;
+            m_current = nullptr;
             return;
         }
     }
