@@ -1,5 +1,5 @@
 //-----------------------------------------------------------------------------
-/** @file TreeReader.cpp */
+/** @file libboardgame_sgf/TreeReader.cpp */
 //-----------------------------------------------------------------------------
 
 #ifdef HAVE_CONFIG_H
@@ -15,7 +15,7 @@ using namespace std;
 //-----------------------------------------------------------------------------
 
 TreeReader::TreeReader()
-    : m_current(0)
+    : m_current(nullptr)
 {
 }
 
@@ -48,7 +48,7 @@ void TreeReader::on_begin_node(bool is_root)
 {
     if (is_root)
     {
-        m_root.reset(Node::create());
+        m_root.reset(new Node());
         m_current = m_root.get();
     }
     else
