@@ -5,16 +5,24 @@
 #ifndef LIBBOARDGAME_SYS_COMPILER_H
 #define LIBBOARDGAME_SYS_COMPILER_H
 
+#include <string>
+#ifdef __GNUC__
+#include <cstdlib>
+#include <cxxabi.h>
+#endif
+
 namespace libboardgame_sys {
 
+using namespace std;
+
 //-----------------------------------------------------------------------------
 
-#if defined __GNUC__
-#define LIBBOARDGAME_FORCE_INLINE __attribute__((always_inline))
+#ifdef __GNUC__
+#define LIBBOARDGAME_FORCE_INLINE inline __attribute__((always_inline))
 #elif defined _MSC_VER
-#define LIBBOARDGAME_FORCE_INLINE __forceinline
+#define LIBBOARDGAME_FORCE_INLINE inline __forceinline
 #else
-#define LIBBOARDGAME_FORCE_INLINE
+#define LIBBOARDGAME_FORCE_INLINE inline
 #endif
 
 #if defined __GNUC__ && ! defined __ICC &&  ! defined __clang__ && \
@@ -24,6 +32,22 @@ namespace libboardgame_sys {
 #define LIBBOARDGAME_FLATTEN
 #endif
 
+template<typename T>
+string get_type_name(const T& t)
+{
+#ifdef __GNUC__
+    int status;
+    char* name_ptr = abi::__cxa_demangle(typeid(t).name(), 0, 0, &status);
+    if (status == 0)
+    {
+        string result(name_ptr);
+        free(name_ptr);
+        return result;
+    }
+#endif
+    return typeid(t).name();
+}
+
 //-----------------------------------------------------------------------------
 
 } // namespace libboardgame_sys
