@@ -1,5 +1,5 @@
 //-----------------------------------------------------------------------------
-/** @file sys/CpuTime.cpp */
+/** @file libboardgame_sys/CpuTime.cpp */
 //-----------------------------------------------------------------------------
 
 #ifdef HAVE_CONFIG_H
@@ -8,9 +8,14 @@
 
 #include "CpuTime.h"
 
+#ifdef _WIN32
+#include <windows.h>
+#endif
+
 #if HAVE_UNISTD_H
 #include <unistd.h>
 #endif
+
 #if HAVE_SYS_TIMES_H
 #include <sys/times.h>
 #endif
@@ -21,7 +26,23 @@ namespace libboardgame_sys {
 
 double cpu_time()
 {
-#if HAVE_UNISTD_H && HAVE_SYS_TIMES_H
+#ifdef _WIN32
+
+    FILETIME create;
+    FILETIME exit;
+    FILETIME sys;
+    FILETIME user;
+    if (! GetProcessTimes(GetCurrentProcess(), &create, &exit, &sys, &user))
+        return -1;
+    ULARGE_INTEGER sys_int;
+    sys_int.LowPart = sys.dwLowDateTime;
+    sys_int.HighPart = sys.dwHighDateTime;
+    ULARGE_INTEGER user_int;
+    user_int.LowPart = user.dwLowDateTime;
+    user_int.HighPart = user.dwHighDateTime;
+    return (sys_int.QuadPart + user_int.QuadPart) * 1e-7;
+
+#elif HAVE_UNISTD_H && HAVE_SYS_TIMES_H
     static double ticks_per_second = double(sysconf(_SC_CLK_TCK));
     struct tms buf;
     if (times(&buf) == clock_t(-1))
@@ -29,8 +50,11 @@ double cpu_time()
     clock_t clock_ticks =
         buf.tms_utime + buf.tms_stime + buf.tms_cutime + buf.tms_cstime;
     return double(clock_ticks) / ticks_per_second;
+
 #else
+
     return -1;
+
 #endif
 }
 
