@@ -1,5 +1,5 @@
 //-----------------------------------------------------------------------------
-/** @file Abort.cpp */
+/** @file libboardgame_util/Abort.cpp */
 //-----------------------------------------------------------------------------
 
 #ifdef HAVE_CONFIG_H
@@ -8,13 +8,17 @@
 
 #include "Abort.h"
 
+#include <atomic>
+
 namespace libboardgame_util {
 
+using namespace std;
+
 //-----------------------------------------------------------------------------
 
 namespace {
 
-volatile bool abort = false;
+atomic<bool> abort(false);
 
 } // namespace
 
@@ -22,17 +26,17 @@ volatile bool abort = false;
 
 void clear_abort()
 {
-    abort = false;
+    abort.store(false, memory_order_seq_cst);
 }
 
 bool get_abort()
 {
-    return abort;
+    return abort.load(memory_order_relaxed);
 }
 
 void set_abort()
 {
-    abort = true;
+    abort.store(true, memory_order_seq_cst);
 }
 
 //----------------------------------------------------------------------------
