@@ -1,5 +1,5 @@
 //-----------------------------------------------------------------------------
-/** @file util/CpuTime.h */
+/** @file libboardgame_util/CpuTime.h */
 //-----------------------------------------------------------------------------
 
 #ifndef LIBBOARDGAME_UTIL_CPU_TIME_H
@@ -11,11 +11,13 @@ namespace libboardgame_util {
 
 //-----------------------------------------------------------------------------
 
+/** CPU time.
+    @ref libboardgame_doc_threadsafe_after_construction */
 class CpuTime
     : public TimeSource
 {
 public:
-    double operator()();
+    double operator()() override;
 };
 //-----------------------------------------------------------------------------
 
