@@ -1,5 +1,5 @@
 //-----------------------------------------------------------------------------
-/** @file Exception.cpp */
+/** @file libboardgame_util/Exception.cpp */
 //-----------------------------------------------------------------------------
 
 #ifdef HAVE_CONFIG_H
@@ -10,8 +10,6 @@
 
 namespace libboardgame_util {
 
-using namespace std;
-
 //-----------------------------------------------------------------------------
 
 Exception::Exception(const string& s)
@@ -19,11 +17,6 @@ Exception::Exception(const string& s)
 {
 }
 
-Exception::Exception(const format& f)
-    : m_s(f.str())
-{
-}
-
 Exception::~Exception() throw()
 {
 }
