@@ -1,5 +1,5 @@
 //-----------------------------------------------------------------------------
-/** @file Exception.h */
+/** @file libboardgame_util/Exception.h */
 //-----------------------------------------------------------------------------
 
 #ifndef LIBBOARDGAME_UTIL_EXCEPTION_H
@@ -7,12 +7,10 @@
 
 #include <exception>
 #include <string>
-#include <boost/format.hpp>
 
 namespace libboardgame_util {
 
 using namespace std;
-using boost::format;
 
 //-----------------------------------------------------------------------------
 
@@ -22,11 +20,9 @@ class Exception
 public:
     Exception(const string& s);
 
-    Exception(const format& f);
-
     virtual ~Exception() throw();
 
-    const char* what() const throw();
+    const char* what() const throw() override;
 
 private:
     string m_s;
