@@ -1,5 +1,5 @@
 //----------------------------------------------------------------------------
-/** @file FastLog.cpp */
+/** @file libboardgame_util/FastLog.cpp */
 //----------------------------------------------------------------------------
 
 #ifdef HAVE_CONFIG_H
@@ -17,13 +17,12 @@ using namespace std;
 
 //----------------------------------------------------------------------------
 
-static_assert(numeric_limits<float>::is_iec559,
-              "libboardgame_util::FastLog requires IEEE 754 float format");
+static_assert(numeric_limits<float>::is_iec559, "");
 
 FastLog::FastLog(int mantissa_bits)
-    : m_mantissa_bits_diff(max_mantissa_bits - mantissa_bits)
+    : m_mantissa_bits_diff(max_mantissa_bits - mantissa_bits),
+      m_table(new float[1 << mantissa_bits])
 {
-    m_table.reset(new float[1 << mantissa_bits]);
     IntFloat x;
     x.m_int = 0x3F800000;
     int incr = (1 << m_mantissa_bits_diff);
