@@ -1,5 +1,5 @@
 //-----------------------------------------------------------------------------
-/** @file Log.cpp */
+/** @file libboardgame_util/Log.cpp */
 //-----------------------------------------------------------------------------
 
 #ifdef HAVE_CONFIG_H
@@ -40,11 +40,6 @@ void log(const string& s)
     log() << line;
 }
 
-void log(const format& f)
-{
-    log(f.str());
-}
-
 void set_log(ostream& out)
 {
     log_stream = &out;
