@@ -1,17 +1,16 @@
 //-----------------------------------------------------------------------------
-/** @file Log.h */
+/** @file libboardgame_util/Log.h */
 //-----------------------------------------------------------------------------
 
 #ifndef LIBBOARDGAME_UTIL_LOG_H
 #define LIBBOARDGAME_UTIL_LOG_H
 
 #include <iosfwd>
-#include <boost/format.hpp>
+#include <string>
 
 namespace libboardgame_util {
 
 using namespace std;
-using boost::format;
 
 //-----------------------------------------------------------------------------
 
@@ -19,8 +18,6 @@ ostream& log();
 
 void log(const string& s);
 
-void log(const format& f);
-
 void set_log(ostream& out);
 
 void set_log_null();
