@@ -9,9 +9,12 @@
 #include <random>
 #include "Assert.h"
 
-// Use fast SSE-based random generator if GCC >=4.8 (non-standard GCC extension)
+// Use fast SIMD-based random generator if GCC.
+// This is a non-standard extension of GCC >=4.8 and so far only available on
+// little-endian systems (last checked with GCC 4.8.2)
 #if defined __GNUC__ \
-    && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 8))
+    && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 8)) \
+    && __BYTE_ORDER__ == __ORDER_LITTLE_ENDIAN__
 #define LIBBOARDGAME_USE_SIMD_MERSENNE_TWISTER
 #endif
 
