@@ -18,7 +18,7 @@ TimeIntervalChecker::TimeIntervalChecker(TimeSource& time_source,
     : IntervalChecker(time_source, time_interval,
                       bind(&TimeIntervalChecker::check_time, this)),
       m_max_time(max_time),
-      m_last_time(m_time_source())
+      m_start_time(m_time_source())
 {
 }
 
@@ -27,16 +27,13 @@ TimeIntervalChecker::TimeIntervalChecker(TimeSource& time_source,
     : IntervalChecker(time_source, max_time > 1 ? 0.1 : 0.1 * max_time,
                       bind(&TimeIntervalChecker::check_time, this)),
       m_max_time(max_time),
-      m_last_time(m_time_source())
+      m_start_time(m_time_source())
 {
 }
 
 bool TimeIntervalChecker::check_time()
 {
-    double time = m_time_source();
-    double diff = time - m_last_time;
-    m_last_time = time;
-    return diff > m_max_time;
+    return m_time_source() - m_start_time > m_max_time;
 }
 
 //-----------------------------------------------------------------------------
