@@ -1,5 +1,5 @@
 //-----------------------------------------------------------------------------
-/** @file TimeSource.h */
+/** @file libboardgame_util/TimeSource.h */
 //-----------------------------------------------------------------------------
 
 #ifndef LIBBOARDGAME_UTIL_TIME_SOURCE_H
@@ -9,6 +9,12 @@ namespace libboardgame_util {
 
 //-----------------------------------------------------------------------------
 
+/** Abstract time source for measuring thinking times for move generation.
+    Typical implementations are wall time, CPU time or mock time sources
+    for unit tests. They do not need to provide high resolutions (but should
+    support at least 100 ms) and should support maximum times of days (or even
+    months).
+    @ref libboardgame_doc_threadsafe_after_construction */
 class TimeSource
 {
 public:
