@@ -1,5 +1,5 @@
 //-----------------------------------------------------------------------------
-/** @file Timer.cpp */
+/** @file libboardgame_util/Timer.cpp */
 //-----------------------------------------------------------------------------
 
 #ifdef HAVE_CONFIG_H
@@ -13,13 +13,14 @@ namespace libboardgame_util {
 //-----------------------------------------------------------------------------
 
 Timer::Timer()
-    : m_time_source(0)
+    : m_time_source(nullptr)
 {
 }
 
 Timer::Timer(TimeSource& time_source)
+    : m_start(time_source()),
+      m_time_source(&time_source)
 {
-    reset(time_source);
 }
 
 void Timer::reset()
