@@ -1,5 +1,5 @@
 //-----------------------------------------------------------------------------
-/** @file Timer.h */
+/** @file libboardgame_util/Timer.h */
 //-----------------------------------------------------------------------------
 
 #ifndef LIBBOARDGAME_UTIL_TIMER_H
@@ -36,7 +36,7 @@ private:
 
 inline double Timer::operator()() const
 {
-    LIBBOARDGAME_ASSERT(m_time_source != 0);
+    LIBBOARDGAME_ASSERT(m_time_source != nullptr);
     return (*m_time_source)() - m_start;
 }
 
