@@ -1,29 +1,29 @@
 //-----------------------------------------------------------------------------
-/** @file WallTime.h */
+/** @file libboardgame_util/WallTime.h */
 //-----------------------------------------------------------------------------
 
 #ifndef LIBBOARDGAME_UTIL_WALL_TIME_H
 #define LIBBOARDGAME_UTIL_WALL_TIME_H
 
-#include <boost/date_time/posix_time/posix_time.hpp>
+#include <chrono>
 #include "TimeSource.h"
 
 namespace libboardgame_util {
 
-using boost::posix_time::ptime;
-
 //-----------------------------------------------------------------------------
 
+/** Wall time.
+    @ref libboardgame_doc_threadsafe_after_construction */
 class WallTime
     : public TimeSource
 {
 public:
     WallTime();
 
-    double operator()();
+    double operator()() override;
 
 private:
-    ptime m_start;
+    std::chrono::system_clock::time_point m_start;
 };
 //-----------------------------------------------------------------------------
 
