@@ -7,6 +7,7 @@
 
 #include "Board.h"
 #include "BoardUpdater.h"
+#include "NodeUtil.h"
 #include "Tree.h"
 
 namespace libpentobi_base {
@@ -16,11 +17,11 @@ namespace libpentobi_base {
 class Game
 {
 public:
-    Game(GameVariant game_variant);
+    Game(Variant variant);
 
     Game(unique_ptr<Node>& root);
 
-    void init(GameVariant game_variant);
+    void init(Variant variant);
 
     void init();
 
@@ -29,13 +30,13 @@ public:
         goto_node() might throw an exception.
         @param root The root node of the SGF tree; the ownership is transfered
         to this class.
-        @throws InvalidPropertyValue, if the root node contains invalid
+        @throws InvalidTree, if the root node contains invalid
         properties */
     void init(unique_ptr<Node>& root);
 
     const Board& get_board() const;
 
-    GameVariant get_game_variant() const;
+    Variant get_variant() const;
 
     const Node& get_current() const;
 
@@ -43,8 +44,13 @@ public:
 
     const Tree& get_tree() const;
 
+    /** Get the current color to play.
+        This takes not into account if the current color to play still has
+        moves available. */
     Color get_to_play() const;
 
+    /** Get the next color to play that still has moves.
+        The colors are tested in playing order starting with get_to_play(). */
     Color get_effective_to_play() const;
 
     /** @param mv
@@ -55,9 +61,10 @@ public:
     void play(Color c, Move mv, bool always_create_new_node);
 
     /** Update game state to a node in the tree.
-        @throws InvalidPropertyValue, if the game was constructed with an
+        @throws InvalidTree, if the game was constructed with an
         external SGF tree and the tree contained invalid property values
-        (syntactically or sematically, like moves on occupied points) */
+        (syntactically or sematically, like moves on occupied points). If an
+        exception is thrown, the current node is not changed. */
     void goto_node(const Node& node);
 
     /** Undo the current move and go to parent node.
@@ -106,14 +113,35 @@ public:
         @pre get_current().has_parent() */
     void truncate();
 
+    void truncate_children();
+
+    /** Replace the game tree by a new one that has the current position
+        as a setup in its root node. */
+    void keep_only_position();
+
+    /** Like keep_only_position() but does not delete the children of the
+        current node. */
+    void keep_only_subtree();
+
     void make_main_variation();
 
+    void move_up_variation();
+
+    void move_down_variation();
+
+    /** Delete all variations but the main variation.
+        If the current node is not in the main variation it will be changed
+        to the node as in libboardgame_sgf::util::back_to_main_variation() */
+    void delete_all_variations();
+
     /** Make the current node the first child of its parent. */
     void make_first_child();
 
+    void set_modified();
+
     void clear_modified();
 
-    bool get_modified() const;
+    bool is_modified() const;
 
     /** Set the AP property at the root node. */
     void set_application(const string& name, const string& version = "");
@@ -128,10 +156,37 @@ public:
 
     void set_date_today();
 
+    /** Get event info (standard property EV) from root node. */
+    string get_event() const;
+
+    void set_event(const string& event);
+
+    /** Get round info (standard property RO) from root node. */
+    string get_round() const;
+
+    void set_round(const string& round);
+
+    /** Get time info (standard property TM) from root node. */
+    string get_time() const;
+
+    void set_time(const string& time);
+
+    bool has_setup() const;
+
+    void add_setup(Color c, Move mv);
+
+    void remove_setup(Color c, Move mv);
+
+    /** See libpentobi_base::Tree::set_player() */
+    void set_player(Color c);
+
+    /** See libpentobi_base::Tree::remove_player() */
+    void remove_player();
+
 private:
     const Node* m_current;
 
-    Board m_bd;
+    unique_ptr<Board> m_bd;
 
     Tree m_tree;
 
@@ -150,7 +205,7 @@ inline double Game::get_bad_move() const
 
 inline const Board& Game::get_board() const
 {
-    return m_bd;
+    return *m_bd;
 }
 
 inline string Game::get_comment() const
@@ -163,9 +218,14 @@ inline string Game::get_date() const
     return m_tree.get_date();
 }
 
+inline string Game::get_event() const
+{
+    return m_tree.get_event();
+}
+
 inline Color Game::get_effective_to_play() const
 {
-    return m_bd.get_effective_to_play();
+    return m_bd->get_effective_to_play();
 }
 
 inline const Node& Game::get_current() const
@@ -173,21 +233,11 @@ inline const Node& Game::get_current() const
     return *m_current;
 }
 
-inline GameVariant Game::get_game_variant() const
-{
-    return m_bd.get_game_variant();
-}
-
 inline double Game::get_good_move() const
 {
     return m_tree.get_good_move(*m_current);
 }
 
-inline bool Game::get_modified() const
-{
-    return m_tree.get_modified();
-}
-
 inline ColorMove Game::get_move() const
 {
     return m_tree.get_move(*m_current);
@@ -205,7 +255,12 @@ inline string Game::get_player_name(Color c) const
 
 inline Color Game::get_to_play() const
 {
-    return m_bd.get_to_play();
+    return m_bd->get_to_play();
+}
+
+inline string Game::get_round() const
+{
+    return m_tree.get_round();
 }
 
 inline const Node& Game::get_root() const
@@ -213,14 +268,29 @@ inline const Node& Game::get_root() const
     return m_tree.get_root();
 }
 
+inline string Game::get_time() const
+{
+    return m_tree.get_time();
+}
+
 inline const Tree& Game::get_tree() const
 {
     return m_tree;
 }
 
+inline bool Game::has_setup() const
+{
+    return libpentobi_base::node_util::has_setup(*m_current);
+}
+
+inline Variant Game::get_variant() const
+{
+    return m_bd->get_variant();
+}
+
 inline void Game::init()
 {
-    init(m_bd.get_game_variant());
+    init(m_bd->get_variant());
 }
 
 inline bool Game::is_doubtful_move() const
@@ -233,6 +303,11 @@ inline bool Game::is_interesting_move() const
     return m_tree.is_interesting_move(*m_current);
 }
 
+inline bool Game::is_modified() const
+{
+    return m_tree.is_modified();
+}
+
 inline void Game::make_first_child()
 {
     m_tree.make_first_child(*m_current);
@@ -243,6 +318,16 @@ inline void Game::make_main_variation()
     m_tree.make_main_variation(*m_current);
 }
 
+inline void Game::move_down_variation()
+{
+    m_tree.move_down(*m_current);
+}
+
+inline void Game::move_up_variation()
+{
+    m_tree.move_up(*m_current);
+}
+
 inline void Game::play(Color c, Move mv, bool always_create_new_node)
 {
     play(ColorMove(c, mv), always_create_new_node);
@@ -278,6 +363,11 @@ inline void Game::set_date(const string& date)
     m_tree.set_date(date);
 }
 
+inline void Game::set_event(const string& event)
+{
+    m_tree.set_event(event);
+}
+
 inline void Game::set_date_today()
 {
     m_tree.set_date_today();
@@ -298,11 +388,31 @@ inline void Game::set_interesting_move()
     m_tree.set_interesting_move(*m_current);
 }
 
+inline void Game::set_modified()
+{
+    m_tree.set_modified();
+}
+
 inline void Game::set_player_name(Color c, const string& name)
 {
     m_tree.set_player_name(c, name);
 }
 
+inline void Game::set_round(const string& round)
+{
+    m_tree.set_round(round);
+}
+
+inline void Game::set_time(const string& time)
+{
+    m_tree.set_time(time);
+}
+
+inline void Game::truncate_children()
+{
+    m_tree.remove_children(*m_current);
+}
+
 //-----------------------------------------------------------------------------
 
 } // namespace libpentobi_base
