@@ -14,13 +14,13 @@ using namespace std;
 
 //-----------------------------------------------------------------------------
 
-Player::Player(const Board& bd)
-    : m_bd(bd)
+Player::~Player() throw()
 {
 }
 
-Player::~Player() throw()
+bool Player::resign() const
 {
+    return false;
 }
 
 //-----------------------------------------------------------------------------
