@@ -14,14 +14,15 @@ namespace libpentobi_base {
 class Player
 {
 public:
-    Player(const Board& bd);
-
     virtual ~Player() throw();
 
-    virtual Move genmove(Color c) = 0;
+    virtual Move genmove(const Board& bd, Color c) = 0;
 
-protected:
-    const Board& m_bd;
+    /** Check if the player wants to resign.
+        This may only be called after a genmove() and returns true if the
+        players wants to resign in the position at the last genmove().
+        The default implementation returns false. */
+    virtual bool resign() const;
 };
 
 //-----------------------------------------------------------------------------
