@@ -16,11 +16,9 @@ using libboardgame_base::SpreadsheetStringRep;
 
 /** Point (coordinate of on-board field) for Blokus game variants.
     Supports RectGeometry up to size 20 and TrigonGeometry up to edge size 9. */
-typedef libboardgame_base::Point<35,20,unsigned short,SpreadsheetStringRep>
+typedef libboardgame_base::Point<35,20,unsigned short,SpreadsheetStringRep,685>
     Point;
 
-typedef Point::Direction Direction;
-
 //-----------------------------------------------------------------------------
 
 } // namespace libpentobi_base
