@@ -8,20 +8,16 @@
 
 #include "SymmetricPoints.h"
 
-#include "libboardgame_base/PointTransform.h"
-
 namespace libpentobi_base {
 
-using libboardgame_base::PointTransfRot180;
-
 //-----------------------------------------------------------------------------
 
-void SymmetricPoints::init(const Geometry& geometry)
+void SymmetricPoints::init(const Geometry& geometry,
+                           const PointTransform<Point>& transform)
 {
     m_symmetric_point.init(geometry);
-    PointTransfRot180<Point> transform;
-    unsigned int width = geometry.get_width();
-    unsigned int height = geometry.get_height();
+    unsigned width = geometry.get_width();
+    unsigned height = geometry.get_height();
     for (Geometry::Iterator i(geometry); i; ++i)
         m_symmetric_point[*i] = transform.get_transformed(*i, width, height);
 }
