@@ -7,8 +7,12 @@
 
 #include "Grid.h"
 
+#include "libboardgame_base/PointTransform.h"
+
 namespace libpentobi_base {
 
+using libboardgame_base::PointTransform;
+
 //-----------------------------------------------------------------------------
 
 /** Lookup table to quickly get points that are symmetric with respect to the
@@ -16,7 +20,7 @@ namespace libpentobi_base {
 class SymmetricPoints
 {
 public:
-    void init(const Geometry& geometry);
+    void init(const Geometry& geometry, const PointTransform<Point>& transform);
 
     Point operator[](Point p) const;
 
