@@ -5,13 +5,19 @@
 #ifndef LIBPENTOBI_GUI_COMPUTER_COLOR_DIALOG_H
 #define LIBPENTOBI_GUI_COMPUTER_COLOR_DIALOG_H
 
+// Needed in the header because moc_*.cxx does not include config.h
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <array>
-#include <QtGui>
-#include "libpentobi_base/GameVariant.h"
+#include <QCheckBox>
+#include <QDialog>
+#include "libpentobi_base/Variant.h"
 #include "libpentobi_base/ColorMap.h"
 
 using namespace std;
-using libpentobi_base::GameVariant;
+using libpentobi_base::Variant;
 using libpentobi_base::Color;
 using libpentobi_base::ColorMap;
 
@@ -23,7 +29,7 @@ class ComputerColorDialog
     Q_OBJECT
 
 public:
-    ComputerColorDialog(QWidget* parent, GameVariant gameVariant,
+    ComputerColorDialog(QWidget* parent, Variant variant,
                         ColorMap<bool>& computerColor);
 
 public slots:
@@ -32,11 +38,13 @@ public slots:
 private:
     ColorMap<bool>& m_computerColor;
 
-    GameVariant m_gameVariant;
+    Variant m_variant;
 
     array<QCheckBox*, 4> m_checkBox;
 
-    void createCheckBox(QLayout* layout, Color c, const QString& text);
+    void createCheckBox(QLayout* layout, Color c);
+
+    QString getPlayerString(Variant variant, Color c);
 };
 
 //-----------------------------------------------------------------------------
