@@ -5,7 +5,14 @@
 #ifndef LIBPENTOBI_GUI_GAME_INFO_DIALOG_H
 #define LIBPENTOBI_GUI_GAME_INFO_DIALOG_H
 
-#include <QtGui>
+// Needed in the header because moc_*.cxx does not include config.h
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include <QDialog>
+#include <QFormLayout>
+#include <QLineEdit>
 #include "libpentobi_base/Game.h"
 
 using namespace std;
@@ -46,6 +53,12 @@ private:
 
     QLineEdit* m_date;
 
+    QLineEdit* m_event;
+
+    QLineEdit* m_round;
+
+    QLineEdit* m_time;
+
     bool acceptLine(QLineEdit* lineEdit, string& value);
 
     QLineEdit* createLine(const QString& label, const string& text);
