@@ -14,8 +14,9 @@ using libpentobi_base::Game;
 
 //-----------------------------------------------------------------------------
 
-void setMarkup(GuiBoard& guiBoard, const Game& game, bool markLastMove,
-               bool markAllMoves, bool markAllLastBySameColor);
+void setMarkup(GuiBoard& guiBoard, const Game& game,
+               unsigned markMovesBegin, unsigned markMovesEnd,
+               bool markVariations);
 
 //-----------------------------------------------------------------------------
 
