@@ -5,7 +5,12 @@
 #ifndef LIBPENTOBI_GUI_LINE_EDIT_H
 #define LIBPENTOBI_GUI_LINE_EDIT_H
 
-#include <QtGui>
+// Needed in the header because moc_*.cxx does not include config.h
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include <QLineEdit>
 
 //-----------------------------------------------------------------------------
 
