@@ -5,13 +5,19 @@
 #ifndef LIBPENTOBI_GUI_ORIENTATION_DISPLAY_H
 #define LIBPENTOBI_GUI_ORIENTATION_DISPLAY_H
 
-#include <QtGui>
+// Needed in the header because moc_*.cxx does not include config.h
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include <QWidget>
 #include "libpentobi_base/Board.h"
 
 using libboardgame_base::Transform;
 using libpentobi_base::Board;
 using libpentobi_base::Color;
 using libpentobi_base::Piece;
+using libpentobi_base::PieceInfo;
 
 //-----------------------------------------------------------------------------
 
@@ -23,23 +29,32 @@ class OrientationDisplay
 public:
     OrientationDisplay(QWidget* parent, const Board& bd);
 
+    int heightForWidth(int width) const;
+
     void selectColor(Color c);
 
     void clearSelectedColor();
 
     void clearSelectedPiece();
 
-    void setSelectedPiece(const Piece& piece);
+    void setSelectedPiece(Piece piece);
 
     void setSelectedPieceTransform(const Transform* transform);
 
+signals:
+    /** A mouse click on the orientation display while a color but no no piece
+        was selected. */
+    void colorClicked(Color color);
+
 protected:
-    void paintEvent(QPaintEvent* event);
+    void mousePressEvent(QMouseEvent* event) override;
+
+    void paintEvent(QPaintEvent* event) override;
 
 private:
     const Board& m_bd;
 
-    const Piece* m_piece;
+    Piece m_piece;
 
     const Transform* m_transform;
 
