@@ -5,7 +5,12 @@
 #ifndef LIBPENTOBI_GUI_SAME_HEIGHT_LAYOUT_H
 #define LIBPENTOBI_GUI_SAME_HEIGHT_LAYOUT_H
 
-#include <QtGui>
+// Needed in the header because moc_*.cxx does not include config.h
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include <QLayout>
 
 //-----------------------------------------------------------------------------
 
@@ -19,7 +24,7 @@ class SameHeightLayout
     Q_OBJECT
 
 public:
-    SameHeightLayout(QWidget* parent = 0);
+    SameHeightLayout(QWidget* parent = nullptr);
 
     ~SameHeightLayout();
 
