@@ -8,26 +8,25 @@
 
 #include "ScoreDisplay.h"
 
+#include <cmath>
+#include <QApplication>
+#include <QPainter>
 #include "libboardgame_util/Log.h"
 #include "libpentobi_gui/Util.h"
 
 using namespace std;
 using libboardgame_util::log;
-using libpentobi_base::game_variant_classic;
-using libpentobi_base::game_variant_classic_2;
-using libpentobi_base::game_variant_duo;
-using libpentobi_base::game_variant_trigon;
-using libpentobi_base::game_variant_trigon_2;
-using libpentobi_base::game_variant_trigon_3;
+using libpentobi_base::ColorIterator;
 
 //-----------------------------------------------------------------------------
 
 ScoreDisplay::ScoreDisplay(QWidget* parent)
-    : QWidget(parent)
+    : QWidget(parent),
+      m_hasMoves(false),
+      m_points(0),
+      m_bonus(0)
 {
-    m_gameVariant = game_variant_classic;
-    m_points.fill(0);
-    m_bonus.fill(0);
+    m_variant = Variant::classic;
     m_font.setStyleStrategy(QFont::PreferOutline);
     setMinimumWidth(300);
     setMinimumHeight(20);
@@ -36,31 +35,63 @@ ScoreDisplay::ScoreDisplay(QWidget* parent)
 
 void ScoreDisplay::drawScore(QPainter& painter, Color c, int x)
 {
-    QColor color = Util::getPaintColor(m_gameVariant, c);
-    QString text = getScoreText(c);
+    auto color = Util::getPaintColor(m_variant, c);
     painter.setPen(Qt::NoPen);
     painter.setBrush(color);
-    int y = static_cast<int>(ceil(0.5 * (height() - m_colorDotSize)));
-    painter.drawEllipse(x,  y, m_colorDotSize, m_colorDotSize);
-    painter.setPen(QApplication::palette().text().color());
-    painter.drawText(x + m_colorDotWidth, 0, getTextWidth(text), height(),
-                     Qt::AlignLeft | Qt::AlignVCenter | Qt::TextDontClip, text);
+    QFontMetrics metrics(m_font);
+    int ascent = metrics.ascent();
+    // y is baseline
+    int y = static_cast<int>(ceil(0.5 * (height() - ascent)) + ascent);
+    painter.setRenderHint(QPainter::Antialiasing, true);
+    painter.drawEllipse(x,  y - m_colorDotSize, m_colorDotSize, m_colorDotSize);
+    QString text = getScoreText(c);
+    bool underline = ! m_hasMoves[c];
+    drawText(painter, text, x + m_colorDotWidth, y, underline);
 }
 
 void ScoreDisplay::drawScore2(QPainter& painter, Color c1, Color c2, int x)
 {
-    QColor color = Util::getPaintColor(m_gameVariant, c1);
-    QString text = getScoreText2(c1, c2);
+    auto color = Util::getPaintColor(m_variant, c1);
     painter.setPen(Qt::NoPen);
     painter.setBrush(color);
-    int y = static_cast<int>(ceil(0.5 * (height() - m_colorDotSize)));
-    painter.drawEllipse(x, y, m_colorDotSize, m_colorDotSize);
-    color = Util::getPaintColor(m_gameVariant, c2);
+    QFontMetrics metrics(m_font);
+    int ascent = metrics.ascent();
+    // y is baseline
+    int y = static_cast<int>(ceil(0.5 * (height() - ascent)) + ascent);
+    painter.setRenderHint(QPainter::Antialiasing, true);
+    painter.drawEllipse(x, y - m_colorDotSize, m_colorDotSize, m_colorDotSize);
+    color = Util::getPaintColor(m_variant, c2);
     painter.setBrush(color);
-    painter.drawEllipse(x + m_colorDotSize, y, m_colorDotSize, m_colorDotSize);
-    painter.setPen(QApplication::palette().text().color());
-    painter.drawText(x + m_twoColorDotWidth, 0, getTextWidth(text), height(),
-                     Qt::AlignLeft | Qt::AlignVCenter | Qt::TextDontClip, text);
+    painter.drawEllipse(x + m_colorDotSize, y - m_colorDotSize, m_colorDotSize,
+                        m_colorDotSize);
+    QString text = getScoreText2(c1, c2);
+    bool underline = (! m_hasMoves[c1] && ! m_hasMoves[c2]);
+    drawText(painter, text, x + m_twoColorDotWidth, y, underline);
+}
+
+void ScoreDisplay::drawText(QPainter& painter, const QString& text, int x,
+                            int y, bool underline)
+{
+    painter.setFont(m_font);
+    QFontMetrics metrics(m_font);
+    auto color = QApplication::palette().color(QPalette::WindowText);
+    painter.setPen(color);
+    painter.setRenderHint(QPainter::Antialiasing, false);
+    painter.drawText(x, y, text);
+    if (underline)
+    {
+        // Draw underline (instead of using an underlined font because the
+        // underline of some fonts is too close to the text and we want it
+        // to be very visible)
+        int lineWidth = metrics.lineWidth();
+        QPen pen(color);
+        pen.setWidth(lineWidth);
+        painter.setPen(pen);
+        y += 2 * lineWidth;
+        if (y > height() - 1)
+            y = height() - 1;
+        painter.drawLine(x, y, x + metrics.width(text), y);
+    }
 }
 
 int ScoreDisplay::getMaxScoreTextWidth() const
@@ -73,8 +104,7 @@ int ScoreDisplay::getMaxScoreTextWidth2() const
     return getTextWidth(getScoreText(88, 20));
 }
 
-QString ScoreDisplay::getScoreText(unsigned int points,
-                                   unsigned int bonus) const
+QString ScoreDisplay::getScoreText(unsigned points, unsigned bonus) const
 {
     QString text;
     text.setNum(points + bonus);
@@ -121,28 +151,25 @@ int ScoreDisplay::getTextWidth(QString text) const
                 metrics.boundingRect(text).width());
 }
 
-void ScoreDisplay::paintEvent(QPaintEvent* event)
+void ScoreDisplay::paintEvent(QPaintEvent*)
 {
     QPainter painter(this);
-    painter.setRenderHint(QPainter::Antialiasing, true);
-    painter.setFont(m_font);
-    m_colorDotSize = 0.8 * m_fontSize;
-    m_colorDotSpace = 0.3 * m_fontSize;
+    m_colorDotSize = static_cast<int>(0.8 * m_fontSize);
+    m_colorDotSpace = static_cast<int>(0.3 * m_fontSize);
     m_colorDotWidth = m_colorDotSize + m_colorDotSpace;
     m_twoColorDotWidth = 2 * m_colorDotSize + m_colorDotSpace;
-    if (m_gameVariant == game_variant_duo)
+    if (m_variant == Variant::duo || m_variant == Variant::junior)
     {
         int textWidthBlue = getScoreTextWidth(Color(0));
         int textWidthGreen = getScoreTextWidth(Color(1));
         int totalWidth = textWidthBlue + textWidthGreen + 2 * m_colorDotWidth;
         qreal pad = qreal(width() - totalWidth) / 3.f;
         qreal x = pad;
-        drawScore(painter, Color(0), x);
-        x+= m_colorDotWidth + textWidthBlue + pad;
-        drawScore(painter, Color(1), x);
+        drawScore(painter, Color(0), static_cast<int>(x));
+        x += m_colorDotWidth + textWidthBlue + pad;
+        drawScore(painter, Color(1), static_cast<int>(x));
     }
-    else if (m_gameVariant == game_variant_classic
-             || m_gameVariant == game_variant_trigon)
+    else if (m_variant == Variant::classic || m_variant == Variant::trigon)
     {
         int textWidthBlue = getScoreTextWidth(Color(0));
         int textWidthYellow = getScoreTextWidth(Color(1));
@@ -153,15 +180,15 @@ void ScoreDisplay::paintEvent(QPaintEvent* event)
             + 4 * m_colorDotWidth;
         qreal pad = qreal(width() - totalWidth) / 5.f;
         qreal x = pad;
-        drawScore(painter, Color(0), x);
-        x+= m_colorDotWidth + textWidthBlue + pad;
-        drawScore(painter, Color(1), x);
-        x+= m_colorDotWidth + textWidthYellow + pad;
-        drawScore(painter, Color(2), x);
-        x+= m_colorDotWidth + textWidthRed + pad;
-        drawScore(painter, Color(3), x);
+        drawScore(painter, Color(0), static_cast<int>(x));
+        x += m_colorDotWidth + textWidthBlue + pad;
+        drawScore(painter, Color(1), static_cast<int>(x));
+        x += m_colorDotWidth + textWidthYellow + pad;
+        drawScore(painter, Color(2), static_cast<int>(x));
+        x += m_colorDotWidth + textWidthRed + pad;
+        drawScore(painter, Color(3), static_cast<int>(x));
     }
-    else if (m_gameVariant == game_variant_trigon_3)
+    else if (m_variant == Variant::trigon_3)
     {
         int textWidthBlue = getScoreTextWidth(Color(0));
         int textWidthYellow = getScoreTextWidth(Color(1));
@@ -171,16 +198,16 @@ void ScoreDisplay::paintEvent(QPaintEvent* event)
             + 3 * m_colorDotWidth;
         qreal pad = qreal(width() - totalWidth) / 4.f;
         qreal x = pad;
-        drawScore(painter, Color(0), x);
-        x+= m_colorDotWidth + textWidthBlue + pad;
-        drawScore(painter, Color(1), x);
-        x+= m_colorDotWidth + textWidthYellow + pad;
-        drawScore(painter, Color(2), x);
+        drawScore(painter, Color(0), static_cast<int>(x));
+        x += m_colorDotWidth + textWidthBlue + pad;
+        drawScore(painter, Color(1), static_cast<int>(x));
+        x += m_colorDotWidth + textWidthYellow + pad;
+        drawScore(painter, Color(2), static_cast<int>(x));
     }
     else
     {
-        LIBBOARDGAME_ASSERT(m_gameVariant == game_variant_classic_2
-                            || m_gameVariant == game_variant_trigon_2);
+        LIBBOARDGAME_ASSERT(m_variant == Variant::classic_2
+                            || m_variant == Variant::trigon_2);
         int textWidthBlueRed = getScoreTextWidth2(Color(0), Color(2));
         int textWidthYellowGreen = getScoreTextWidth2(Color(1), Color(3));
         int textWidthBlue = getScoreTextWidth(Color(0));
@@ -193,41 +220,43 @@ void ScoreDisplay::paintEvent(QPaintEvent* event)
             + 2 * m_twoColorDotWidth + 4 * m_colorDotWidth;
         qreal pad = qreal(width() - totalWidth) / 7.f;
         qreal x = pad;
-        drawScore2(painter, Color(0), Color(2), x);
-        x+= m_twoColorDotWidth + textWidthBlueRed + pad;
-        drawScore2(painter, Color(1), Color(3), x);
-        x+= m_twoColorDotWidth + textWidthYellowGreen + pad;
-        drawScore(painter, Color(0), x);
-        x+= m_colorDotWidth + textWidthBlue + pad;
-        drawScore(painter, Color(1), x);
-        x+= m_colorDotWidth + textWidthYellow + pad;
-        drawScore(painter, Color(2), x);
-        x+= m_colorDotWidth + textWidthRed + pad;
-        drawScore(painter, Color(3), x);
+        drawScore2(painter, Color(0), Color(2), static_cast<int>(x));
+        x += m_twoColorDotWidth + textWidthBlueRed + pad;
+        drawScore2(painter, Color(1), Color(3), static_cast<int>(x));
+        x += m_twoColorDotWidth + textWidthYellowGreen + pad;
+        drawScore(painter, Color(0), static_cast<int>(x));
+        x += m_colorDotWidth + textWidthBlue + pad;
+        drawScore(painter, Color(1), static_cast<int>(x));
+        x += m_colorDotWidth + textWidthYellow + pad;
+        drawScore(painter, Color(2), static_cast<int>(x));
+        x += m_colorDotWidth + textWidthRed + pad;
+        drawScore(painter, Color(3), static_cast<int>(x));
     }
 }
 
-void ScoreDisplay::resizeEvent(QResizeEvent* event)
+void ScoreDisplay::resizeEvent(QResizeEvent*)
 {
-    m_fontSize = floor(0.7 * height());
+    m_fontSize = static_cast<int>(floor(0.6 * height()));
     m_font.setPixelSize(m_fontSize);
 }
 
 void ScoreDisplay::updateScore(const Board& bd)
 {
-    GameVariant variant = bd.get_game_variant();
-    bool hasChanged = (m_gameVariant != variant);
-    m_gameVariant = variant;
-    for (unsigned int i = 0; i < bd.get_nu_colors(); ++i)
+    auto variant = bd.get_variant();
+    bool hasChanged = (m_variant != variant);
+    m_variant = variant;
+    for (ColorIterator i(bd.get_nu_colors()); i; ++i)
     {
-        Color c(i);
-        unsigned int points = bd.get_points(c);
-        unsigned int bonus = bd.get_bonus(c);
-        if (m_points[c] != points || m_bonus[c] != bonus)
+        bool hasMoves = bd.has_moves(*i);
+        unsigned points = bd.get_points(*i);
+        unsigned bonus = bd.get_bonus(*i);
+        if (hasMoves != m_hasMoves[*i] || m_points[*i] != points
+            || m_bonus[*i] != bonus)
         {
             hasChanged = true;
-            m_points[c] = points;
-            m_bonus[c] = bonus;
+            m_hasMoves[*i] = hasMoves;
+            m_points[*i] = points;
+            m_bonus[*i] = bonus;
         }
     }
     if (hasChanged)
