@@ -5,24 +5,45 @@
 #ifndef PENTOBI_MAIN_WINDOW_H
 #define PENTOBI_MAIN_WINDOW_H
 
-#include <QtGui>
+// Needed in the header because moc_*.cxx does not include config.h
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
+#include <QElapsedTimer>
+#include <QFutureWatcher>
+#include <QMainWindow>
+#include "RatingHistory.h"
 #include "libpentobi_base/ColorMap.h"
 #include "libpentobi_base/Game.h"
 #include "libpentobi_mcts/Player.h"
-#include "libpentobi_gui/GuiBoard.h"
-#include "libpentobi_gui/HelpWindow.h"
-#include "libpentobi_gui/OrientationDisplay.h"
-#include "libpentobi_gui/PieceSelector.h"
-#include "libpentobi_gui/ScoreDisplay.h"
+
+class QActionGroup;
+class QLabel;
+class QMessageBox;
+class QPlainTextEdit;
+class QSplitter;
+class AnalyzeGameWindow;
+class GuiBoard;
+class HelpWindow;
+class LeaveFullscreenButton;
+class OrientationDisplay;
+class PieceSelector;
+class RatingDialog;
+class ScoreDisplay;
 
 using namespace std;
 using libboardgame_sgf::Node;
+using libboardgame_base::Transform;
 using libboardgame_util::ArrayList;
 using libboardgame_util::Exception;
 using libpentobi_base::Board;
 using libpentobi_base::ColorMap;
+using libpentobi_base::ColorMove;
 using libpentobi_base::Game;
-using libpentobi_base::GameVariant;
+using libpentobi_base::Piece;
+using libpentobi_base::Point;
+using libpentobi_base::Variant;
 using libpentobi_base::Move;
 using libpentobi_mcts::Player;
 
@@ -34,15 +55,19 @@ class MainWindow
     Q_OBJECT
 
 public:
-    MainWindow(const QString& initialFile = QString(), bool noBook = false);
+    MainWindow(const QString& initialFile = "", const QString& manualDir = "",
+               const QString& booksDir = "", bool noBook = false,
+               unsigned nu_threads = 0, size_t memory = 0);
 
-    bool eventFilter(QObject* watched, QEvent* event);
+    bool eventFilter(QObject* object, QEvent* event);
 
     QSize sizeHint() const;
 
 public slots:
     void about();
 
+    void analyzeGame();
+
     void backward();
 
     void backward10();
@@ -51,9 +76,13 @@ public slots:
 
     void beginning();
 
+    void beginningOfBranch();
+
     void clearSelectedPiece();
 
-    void computerColor();
+    void computerColors();
+
+    void deleteAllVariations();
 
     void end();
 
@@ -75,18 +104,34 @@ public slots:
 
     void gotoMove();
 
-    void help();
+    /** Go to a node if a node with a position defined by a sequence of moves
+        still exists. */
+    void gotoPosition(Variant variant, const vector<ColorMove>& moves);
 
-    void humanPlay(Color c, Move mv);
+    void help();
 
     void gameInfo();
 
+    /** Abort current move generation and don't play a move. */
     void interrupt();
 
+    /** Abort current move generation and play best move found so far. */
+    void interruptPlay();
+
+    void keepOnlyPosition();
+
+    void keepOnlySubtree();
+
     void makeMainVariation();
 
+    void moveDownVariation();
+
+    void moveUpVariation();
+
     void newGame();
 
+    void newRatedGame();
+
     void nextVariation();
 
     void nextVariation10();
@@ -97,10 +142,16 @@ public slots:
 
     void open();
 
-    void open(const QString& file, bool isTemporary = false);
+    bool open(const QString& file, bool isTemporary = false);
+
+    void placePiece(Color c, Move mv);
 
     void play();
 
+    void playSingleMove();
+
+    void pointClicked(Point p);
+
     void previousPiece();
 
     void previousTransform();
@@ -109,8 +160,6 @@ public slots:
 
     void previousVariation10();
 
-    void quit();
-
     void rotatePieceAnticlockwise();
 
     void rotatePieceClockwise();
@@ -159,53 +208,101 @@ public slots:
 
     void selectPieceZ();
 
-    void selectPiece(Color c, const Piece& piece);
+    void selectPiece(Color c, Piece piece);
 
-    void selectPiece(Color c, const Piece& piece, const Transform* transform);
+    void selectPiece(Color c, Piece piece, const Transform* transform);
 
     void setLevel(int level);
 
     void truncate();
 
+    void truncateChildren();
+
     void undo();
 
-protected:
-    void closeEvent(QCloseEvent* event);
+    void showToolbar(bool checked);
 
-    void wheelEvent(QWheelEvent* event);
+    void showVariations(bool checked);
+
+    void showRating();
+
+    void setDeterministic();
+
+protected:
+    void closeEvent(QCloseEvent* event) override;
+
+    void wheelEvent(QWheelEvent* event) override;
 
 private:
     struct GenMoveResult
     {
+        bool playSingleMove;
+
         Color color;
 
         Move move;
 
-        unsigned int genMoveId;
+        unsigned genMoveId;
     };
 
     /** Possible values for m_level are in 1..maxLevel */
-    static const int maxLevel = 6;
+    static const int maxLevel = 8;
 
     static const int maxRecentFiles = 9;
 
     unique_ptr<Game> m_game;
 
-    Color m_toPlay;
+    Color m_currentColor;
 
     unique_ptr<Player> m_player;
 
     bool m_isGenMoveRunning;
 
-    bool m_lastMoveByComputer;
+    bool m_isAnalyzeRunning;
+
+    /** Should the computer generate a move if it is its turn?
+        Enabled on game start (if the computer plays at least one color)
+        or after selecting Play. Disabled when navigating in the game. */
+    bool m_autoPlay;
 
     /** Flag indicating that the position after the last move played was
         a terminal position. */
     bool m_gameFinished;
 
+    bool m_isRated;
+
+    /** Flag set while setting the text in m_comment for fast return in the
+        textChanged() handler.
+        Used because QPlainTextEdit does not have a textEdited() signal and
+        we only need to handle edits. */
+    bool m_ignoreCommentTextChanged;
+
+    bool m_genMoveInterrupted;
+
+    /** Color played by the user in a rated game.
+        Only defined if m_isRated is true. In game variants with multiple
+        colors per player, the user plays all colors of the player with
+        this color. */
+    Color m_ratedGameColor;
+
     /** Integer ID assigned to the currently running move generation.
         Used to ignore finished events from canceled move generations. */
-    unsigned int m_genMoveId;
+    unsigned m_genMoveId;
+
+    /** Beginning of move number range of last moves played by the computer
+        without pause.
+        Used to mark all last moves played by the computer if it plays several
+        moves in a row because the other players have no more moves. Otherwise,
+        it would be hard to see what the last moves were if the computer plays
+        quickly. A value of 0 means that there are no last moves played by
+        the computer to be marked. */
+    unsigned m_lastComputerMovesBegin;
+
+    /** End (inclusive) of move number range of last moves played by the
+        computer without pause.
+        Only defined if m_lastComputerMovesBegin is not 0.
+        @see m_lastComputerMovesBegin */
+    unsigned m_lastComputerMovesEnd;
 
     /** Current playing level of m_player.
         Only use if m_useTimeLimit is false. Possible values for m_level are in
@@ -215,13 +312,15 @@ private:
         generation. */
     int m_level;
 
+    unique_ptr<RatingHistory> m_history;
+
     QToolBar* m_toolBar;
 
     GuiBoard* m_guiBoard;
 
-    ColorMap<bool> m_computerColor;
+    QString m_manualDir;
 
-    ColorMap<bool> m_noMovesAvailableShown;
+    ColorMap<bool> m_computerColors;
 
     ColorMap<PieceSelector*> m_pieceSelector;
 
@@ -233,10 +332,16 @@ private:
 
     QPlainTextEdit* m_comment;
 
-    HelpWindow* m_help_window;
+    HelpWindow* m_helpWindow;
+
+    RatingDialog* m_ratingDialog;
+
+    AnalyzeGameWindow* m_analyzeGameWindow;
 
     QAction* m_actionAbout;
 
+    QAction* m_actionAnalyzeGame;
+
     QAction* m_actionBackward;
 
     QAction* m_actionBackward10;
@@ -247,11 +352,15 @@ private:
 
     QAction* m_actionBeginning;
 
+    QAction* m_actionBeginningOfBranch;
+
     QAction* m_actionClearSelectedPiece;
 
-    QAction* m_actionComputerColor;
+    QAction* m_actionComputerColors;
 
-    QAction* m_actionCoordinateLabels;
+    QAction* m_actionCoordinates;
+
+    QAction* m_actionDeleteAllVariations;
 
     QAction* m_actionDoubtfulMove;
 
@@ -277,17 +386,19 @@ private:
 
     QAction* m_actionGameInfo;
 
-    QAction* m_actionGameVariantClassic;
+    QAction* m_actionVariantClassic;
 
-    QAction* m_actionGameVariantClassic2;
+    QAction* m_actionVariantClassic2;
 
-    QAction* m_actionGameVariantDuo;
+    QAction* m_actionVariantDuo;
 
-    QAction* m_actionGameVariantTrigon;
+    QAction* m_actionVariantJunior;
 
-    QAction* m_actionGameVariantTrigon2;
+    QAction* m_actionVariantTrigon;
 
-    QAction* m_actionGameVariantTrigon3;
+    QAction* m_actionVariantTrigon2;
+
+    QAction* m_actionVariantTrigon3;
 
     QAction* m_actionGoodMove;
 
@@ -299,16 +410,28 @@ private:
 
     QAction* m_actionInterrupt;
 
+    QAction* m_actionInterruptPlay;
+
+    QAction* m_actionKeepOnlyPosition;
+
+    QAction* m_actionKeepOnlySubtree;
+
+    QAction* m_actionLeaveFullscreen;
+
     QAction* m_actionLevel[maxLevel];
 
     QAction* m_actionMakeMainVariation;
 
+    QAction* m_actionMoveDownVariation;
+
     QAction* m_actionMoveNumbersAll;
 
     QAction* m_actionMoveNumbersLast;
 
     QAction* m_actionMoveNumbersNone;
 
+    QAction* m_actionMoveUpVariation;
+
     QAction* m_actionMoveSelectedPieceLeft;
 
     QAction* m_actionMoveSelectedPieceRight;
@@ -325,7 +448,9 @@ private:
 
     QAction* m_actionNextVariation10;
 
-    QAction* m_actionNewGame;
+    QAction* m_actionNew;
+
+    QAction* m_actionNewRatedGame;
 
     QAction* m_actionNoMoveAnnotation;
 
@@ -335,6 +460,8 @@ private:
 
     QAction* m_actionPlay;
 
+    QAction* m_actionPlaySingleMove;
+
     QAction* m_actionPreviousPiece;
 
     QAction* m_actionPreviousTransform;
@@ -357,6 +484,8 @@ private:
 
     QAction* m_actionShowComment;
 
+    QAction* m_actionShowRating;
+
     QAction* m_actionShowToolbar;
 
     QAction* m_actionSelectNextColor;
@@ -399,8 +528,24 @@ private:
 
     QAction* m_actionSelectPieceZ;
 
+    QAction* m_actionSetupMode;
+
+    QAction* m_actionToolBarNoText;
+
+    QAction* m_actionToolBarTextBesideIcons;
+
+    QAction* m_actionToolBarTextBelowIcons;
+
+    QAction* m_actionToolBarTextOnly;
+
+    QAction* m_actionToolBarTextSystem;
+
     QAction* m_actionTruncate;
 
+    QAction* m_actionTruncateChildren;
+
+    QAction* m_actionShowVariations;
+
     QAction* m_actionUndo;
 
     QAction* m_actionVeryGoodMove;
@@ -411,19 +556,37 @@ private:
 
     QMenu* m_menuOpenRecent;
 
-    QToolButton* m_buttonFullscreen;
+    QMenu* m_menuToolBarText;
+
+    QLabel* m_setupModeLabel;
+
+    QLabel* m_ratedGameLabel;
 
     QFutureWatcher<GenMoveResult> m_genMoveWatcher;
 
+    QElapsedTimer m_genMoveTime;
+
     QString m_file;
 
     unique_ptr<ArrayList<Move, Move::range>> m_legalMoves;
 
-    unsigned int m_legalMoveIndex;
+    unsigned m_legalMoveIndex;
 
     QLabel* m_moveNumber;
 
-    GenMoveResult asyncGenMove(Color c, int genMoveId);
+    LeaveFullscreenButton* m_leaveFullscreenButton;
+
+    int m_lastRemainingSeconds;
+
+    int m_lastRemainingMinutes;
+
+    /** Is the current game a game loaded from the autosave file?
+        If yes, we need it to save again on quit even if it was not modified.
+        Note that the autosave game is deleted after loading to avoid that
+        it is used twice if two instances of Pentobi are started. */
+    bool m_isAutoSaveLoaded;
+
+    GenMoveResult asyncGenMove(Color c, int genMoveId, bool playSingleMove);
 
     bool checkSave();
 
@@ -431,6 +594,8 @@ private:
 
     void clearFile();
 
+    QAction* createAction(const QString& text = "");
+
     void createActions();
 
     QWidget* createCentralWidget();
@@ -442,17 +607,17 @@ private:
 
     void createMenu();
 
-    QWidget* createOrientationButtonBoxLeft();
+    QLayout* createOrientationButtonBoxLeft();
 
-    QWidget* createOrientationButtonBoxRight();
+    QLayout* createOrientationButtonBoxRight();
 
-    QWidget* createOrientationSelector();
+    QLayout* createOrientationSelector();
 
-    QWidget* createRightPanel();
+    QLayout* createRightPanel();
 
     void createToolBar();
 
-    void cancelGenMove();
+    void cancelThread();
 
     void checkComputerMove();
 
@@ -462,10 +627,16 @@ private:
 
     void deleteAutoSaveFile();
 
-    void genMove();
+    void enablePieceSelector(Color c);
+
+    void gameOver();
+
+    void genMove(bool playSingleMove = false);
 
     const Board& getBoard() const;
 
+    Variant getVariant() const;
+
     QString getFilter() const;
 
     QString getLastDir();
@@ -476,72 +647,82 @@ private:
 
     void initGame();
 
-    void initGameVariantActions();
+    void initVariantActions();
 
     void initPieceSelectors();
 
+    void leaveSetupMode();
+
     void play(Color c, Move mv);
 
     bool save(const QString& file);
 
-    void setGameVariant(GameVariant gameVariant);
+    void searchCallback(double elapsedSeconds, double remainingSeconds);
 
-    void setMoveNumberText();
+    void setCommentText(const QString& text);
+
+    void setVariant(Variant variant);
+
+    void setPlayToolTip();
+
+    void setRated(bool isRated);
 
     void setFile(const QString& file);
 
-    void showError(const QString& message,
-                   const QString& infoText = QString(),
-                   const QString& detailText = QString());
+    void showError(const QString& message, const QString& infoText = "",
+                   const QString& detailText = "");
 
-    void showGameOver();
-
-    void showInfo(const QString& message, const QString& infoText = QString(),
-                  const QString& detailText = QString());
+    void showInfo(const QString& message, const QString& infoText = "",
+                  const QString& detailText = "", bool withIcon = false);
 
     void showInvalidFile(QString file, const Exception& e);
 
-    void showMessage(QMessageBox::Icon icon, const QString& text,
-                     const QString& infoText, const QString& detailText);
+    void showStatus(const QString& text, bool temporary = false);
 
-    void showNoMovesAvailable(Color c);
-
-    QMessageBox::StandardButton showQuestion(const QString& text,
-                                             const QString& infoText,
-                                         QMessageBox::StandardButtons buttons);
+    void updateMoveNumber();
 
     void updateWindow(bool currentNodeChanged);
 
+    void updateWindowModified();
+
     void updateComment();
 
     void updateMoveAnnotationActions();
 
+    void loadHistory();
+
     void updateRecentFiles();
 
     void updateFlipActions();
 
+    bool writeGame(const string& file);
+
 private slots:
+    void analyzeGameFinished();
+
     void badMove(bool checked);
 
     void commentChanged();
 
-    void coordinateLabels(bool checked);
+    void coordinates(bool checked);
 
     void doubtfulMove(bool checked);
 
-    void fullscreen(bool checked);
+    void fullscreen();
 
-    void gameVariantClassic(bool checked);
+    void variantClassic(bool checked);
 
-    void gameVariantClassic2(bool checked);
+    void variantClassic2(bool checked);
 
-    void gameVariantDuo(bool checked);
+    void variantDuo(bool checked);
 
-    void gameVariantTrigon(bool checked);
+    void variantJunior(bool checked);
 
-    void gameVariantTrigon2(bool checked);
+    void variantTrigon(bool checked);
 
-    void gameVariantTrigon3(bool checked);
+    void variantTrigon2(bool checked);
+
+    void variantTrigon3(bool checked);
 
     void genMoveFinished();
 
@@ -549,12 +730,21 @@ private slots:
 
     void interestingMove(bool checked);
 
+    void leaveFullscreen();
+
     void noMoveAnnotation(bool checked);
 
     void openRecentFile();
 
-    void selectNamedPiece(const char* name1, const char* name2 = 0,
-                          const char* name3 = 0, const char* name4 = 0);
+    void orientationDisplayColorClicked(Color c);
+
+    void rememberFile(const QString& file);
+
+    void rememberDir(const QString& file);
+
+    void selectNamedPiece(const char* name1, const char* name2 = nullptr,
+                          const char* name3 = nullptr,
+                          const char* name4 = nullptr);
 
     void setLevel(bool checked);
 
@@ -564,11 +754,21 @@ private slots:
 
     void setMoveNumbersNone(bool checked);
 
+    void setSetupPlayer();
+
+    void setupMode(bool checked);
+
     void showComment(bool checked);
 
-    void showStatus(const QString& text, bool temporary = false);
+    void toolBarNoText(bool checked);
 
-    void splitterMoved(int pos, int index);
+    void toolBarTextBesideIcons(bool checked);
+
+    void toolBarTextBelowIcons(bool checked);
+
+    void toolBarTextOnly(bool checked);
+
+    void toolBarTextSystem(bool checked);
 
     void veryBadMove(bool checked);
 
@@ -580,6 +780,11 @@ inline const Board& MainWindow::getBoard() const
     return m_game->get_board();
 }
 
+inline Variant MainWindow::getVariant() const
+{
+    return m_game->get_variant();
+}
+
 //-----------------------------------------------------------------------------
 
 #endif // PENTOBI_MAIN_WINDOW_H
