@@ -11,10 +11,9 @@
 namespace pentobi_gtp {
 
 using namespace std;
-using boost::filesystem::path;
 using libboardgame_gtp::Arguments;
 using libboardgame_gtp::Response;
-using libpentobi_base::GameVariant;
+using libpentobi_base::Variant;
 using libpentobi_mcts::Player;
 using libpentobi_mcts::Search;
 
@@ -24,26 +23,34 @@ class Engine
     : public libpentobi_base::Engine
 {
 public:
-    Engine(GameVariant game_variant, int level = 5, bool use_book = true,
-           const path& application_dir_path = path());
+    Engine(Variant variant, int level = 5,
+           bool use_book = true, const string& books_dir = "",
+           unsigned nu_threads = 0, size_t memory = 0);
 
     ~Engine() throw();
 
-    void cmd_gen_playout_move(Response& response);
-
-    void cmd_param(const Arguments& args, Response& response);
-
-    void cmd_get_value(Response& response);
-
-    void cmd_move_values(Response& response);
+    void cmd_gen_playout_move(Response&);
+    void cmd_param(const Arguments&, Response&);
+    void cmd_get_value(Response&);
+    void cmd_move_values(Response&);
+    void cmd_name(Response&);
+    void cmd_moves_stat(const Arguments&, Response&);
+    void cmd_save_tree(const Arguments&);
+    void cmd_version(Response&);
 
     Player& get_mcts_player();
 
+    /** @see Search::set_deterministic() */
+    void set_deterministic();
+
+    /** @see Player::use_cpu_time() */
+    void use_cpu_time(bool enable);
+
 private:
     unique_ptr<libpentobi_base::Player> m_player;
 
-    void create_player(GameVariant game_variant,
-                       const path& application_dir_path);
+    void create_player(Variant variant, const string& books_dir,
+                       unsigned nu_threads, size_t memory);
 
     Search& get_search();
 };
