@@ -1,5 +1,5 @@
 //-----------------------------------------------------------------------------
-/** @file sgf/UtilTest.cpp */
+/** @file unittest/libboardgame_sgf/UtilTest.cpp */
 //-----------------------------------------------------------------------------
 
 #ifdef HAVE_CONFIG_H
@@ -18,8 +18,8 @@ using namespace libboardgame_sgf::util;
 
 LIBBOARDGAME_TEST_CASE(sgf_util_get_path_from_root)
 {
-    unique_ptr<Node> root(Node::create());
-    const Node& child = root->create_new_child();
+    unique_ptr<Node> root(new Node());
+    auto& child = root->create_new_child();
     vector<const Node*> path;
     get_path_from_root(child, path);
     LIBBOARDGAME_CHECK_EQUAL(path.size(), 2u);
